@@ -83,22 +83,17 @@ typedef enum {
  * @PANGO_VARIANT_SMALL_CAPS: A font with the lower case characters
  *   replaced by smaller variants of the capital characters.
  * @PANGO_VARIANT_ALL_SMALL_CAPS: A font with all characters
- *   replaced by smaller variants of the capital characters.
- *   Since: 1.50
+ *   replaced by smaller variants of the capital characters. Since: 1.50
  * @PANGO_VARIANT_PETITE_CAPS: A font with the lower case characters
  *   replaced by smaller variants of the capital characters.
- *   Petite Caps can be even smaller than Small Caps.
- *   Since: 1.50
+ *   Petite Caps can be even smaller than Small Caps. Since: 1.50
  * @PANGO_VARIANT_ALL_PETITE_CAPS: A font with all characters
  *   replaced by smaller variants of the capital characters.
- *   Petite Caps can be even smaller than Small Caps.
- *   Since: 1.50
+ *   Petite Caps can be even smaller than Small Caps. Since: 1.50
  * @PANGO_VARIANT_UNICASE: A font with the upper case characters
- *   replaced by smaller variants of the capital letters.
- *   Since: 1.50
+ *   replaced by smaller variants of the capital letters. Since: 1.50
  * @PANGO_VARIANT_TITLE_CAPS: A font with capital letters that
- *   are more suitable for all-uppercase titles.
- *   Since: 1.50
+ *   are more suitable for all-uppercase titles. Since: 1.50
  *
  * An enumeration specifying capitalization variant of the font.
  */
@@ -114,23 +109,23 @@ typedef enum {
 
 /**
  * PangoWeight:
- * @PANGO_WEIGHT_THIN: the thin weight (= 100; Since: 1.24)
+ * @PANGO_WEIGHT_THIN: the thin weight (= 100) Since: 1.24
  * @PANGO_WEIGHT_ULTRALIGHT: the ultralight weight (= 200)
  * @PANGO_WEIGHT_LIGHT: the light weight (= 300)
- * @PANGO_WEIGHT_SEMILIGHT: the semilight weight (= 350; Since: 1.36.7)
- * @PANGO_WEIGHT_BOOK: the book weight (= 380; Since: 1.24)
+ * @PANGO_WEIGHT_SEMILIGHT: the semilight weight (= 350) Since: 1.36.7
+ * @PANGO_WEIGHT_BOOK: the book weight (= 380) Since: 1.24)
  * @PANGO_WEIGHT_NORMAL: the default weight (= 400)
- * @PANGO_WEIGHT_MEDIUM: the normal weight (= 500; Since: 1.24)
+ * @PANGO_WEIGHT_MEDIUM: the normal weight (= 500) Since: 1.24
  * @PANGO_WEIGHT_SEMIBOLD: the semibold weight (= 600)
  * @PANGO_WEIGHT_BOLD: the bold weight (= 700)
  * @PANGO_WEIGHT_ULTRABOLD: the ultrabold weight (= 800)
  * @PANGO_WEIGHT_HEAVY: the heavy weight (= 900)
- * @PANGO_WEIGHT_ULTRAHEAVY: the ultraheavy weight (= 1000; Since: 1.24)
+ * @PANGO_WEIGHT_ULTRAHEAVY: the ultraheavy weight (= 1000) Since: 1.24
  *
  * An enumeration specifying the weight (boldness) of a font.
  *
- * This is a numerical value ranging from 100 to 1000, but there
- * are some predefined values.
+ * Weight is specified as a numeric value ranging from 100 to 1000.
+ * This enumeration simply provides some common, predefined values.
  */
 typedef enum {
   PANGO_WEIGHT_THIN = 100,
@@ -637,6 +632,11 @@ PangoLanguage **      pango_font_get_languages     (PangoFont        *font);
 PANGO_AVAILABLE_IN_1_50
 GBytes *              pango_font_serialize         (PangoFont        *font);
 
+PANGO_AVAILABLE_IN_1_50
+PangoFont *           pango_font_deserialize       (PangoContext     *context,
+                                                    GBytes           *bytes,
+                                                    GError          **error);
+
 /**
  * PANGO_GLYPH_EMPTY:
  *
