@@ -30,10 +30,13 @@
 #include "config.h"
 #include <pango/pangocairo.h>
 #include "test-common.h"
+#include "validate-log-attrs.h"
 
 
 static PangoContext *context;
 
+static gboolean opt_hex_chars;
+
 static gboolean
 test_file (const gchar *filename, GString *string)
 {
@@ -46,7 +49,7 @@ test_file (const gchar *filename, GString *string)
   int len2;
   char *p;
   int i;
-  GString *s1, *s2, *s3, *s4, *s5;
+  GString *s1, *s2, *s3, *s4, *s5, *s6;
   int m;
   char *test;
   char *text;
@@ -95,6 +98,11 @@ test_file (const gchar *filename, GString *string)
 
   g_assert_cmpint (len, ==, len2);
   g_assert_true (memcmp (attrs, attrs2, sizeof (PangoLogAttr) * len) == 0);
+  if (!pango_validate_log_attrs (text, length, attrs, len, &error))
+    {
+      g_warning ("%s: Log attrs invalid: %s", filename, error->message);
+//      g_assert_not_reached ();
+    }
 
   layout2 = pango_layout_copy (layout);
   attrs2 = pango_layout_get_log_attrs_readonly (layout2, &len2);
@@ -109,6 +117,7 @@ test_file (const gchar *filename, GString *string)
   s3 = g_string_new ("Sentences:");
   s4 = g_string_new ("Words:");
   s5 = g_string_new ("Graphemes:");
+  s6 = g_string_new ("Hyphens:");
 
   g_string_append (string, "Text: ");
 
@@ -119,6 +128,7 @@ test_file (const gchar *filename, GString *string)
   g_string_append_printf (s3, "%*s", (int)(m - s3->len), "");
   g_string_append_printf (s4, "%*s", (int)(m - s4->len), "");
   g_string_append_printf (s5, "%*s", (int)(m - s5->len), "");
+  g_string_append_printf (s6, "%*s", (int)(m - s6->len), "");
   g_string_append_printf (string, "%*s", (int)(m - strlen ("Text: ")), "");
 
   for (i = 0, p = text; i < len; i++, p = g_utf8_next_char (p))
@@ -129,6 +139,7 @@ test_file (const gchar *filename, GString *string)
       int o = 0;
       int s = 0;
       int g = 0;
+      int h = 0;
 
       if (log.is_mandatory_break)
         {
@@ -195,7 +206,18 @@ test_file (const gchar *filename, GString *string)
           g++;
         }
 
-      m = MAX (MAX (MAX (b, w), MAX (o, s)), g);
+      if (log.break_removes_preceding)
+        {
+          g_string_append (s6, "r");
+          h++;
+        }
+      if (log.break_inserts_hyphen)
+        {
+          g_string_append (s6, "i");
+          h++;
+        }
+
+      m = MAX (MAX (MAX (b, w), MAX (o, s)), MAX (g, h));
 
       g_string_append_printf (string, "%*s", m, "");
       g_string_append_printf (s1, "%*s", m - b, "");
@@ -203,6 +225,7 @@ test_file (const gchar *filename, GString *string)
       g_string_append_printf (s3, "%*s", m - s, "");
       g_string_append_printf (s4, "%*s", m - o, "");
       g_string_append_printf (s5, "%*s", m - g, "");
+      g_string_append_printf (s6, "%*s", m - h, "");
 
       if (i < len - 1)
         {
@@ -215,8 +238,10 @@ test_file (const gchar *filename, GString *string)
               g_string_append (s3, "   ");
               g_string_append (s4, "   ");
               g_string_append (s5, "   ");
+              g_string_append (s6, "   ");
             }
-          else if (g_unichar_isgraph (ch) &&
+          else if (!opt_hex_chars &&
+                   g_unichar_isgraph (ch) &&
                    !(g_unichar_type (ch) == G_UNICODE_LINE_SEPARATOR ||
                      g_unichar_type (ch) == G_UNICODE_PARAGRAPH_SEPARATOR))
             {
@@ -228,6 +253,7 @@ test_file (const gchar *filename, GString *string)
               g_string_append (s3, " ");
               g_string_append (s4, " ");
               g_string_append (s5, " ");
+              g_string_append (s6, " ");
             }
           else
             {
@@ -238,6 +264,7 @@ test_file (const gchar *filename, GString *string)
               g_string_append_printf (s3, "%*s", (int)strlen (str), "");
               g_string_append_printf (s4, "%*s", (int)strlen (str), "");
               g_string_append_printf (s5, "%*s", (int)strlen (str), "");
+              g_string_append_printf (s6, "%*s", (int)strlen (str), "");
               g_free (str);
             }
         }
@@ -253,12 +280,15 @@ test_file (const gchar *filename, GString *string)
   g_string_append (string, "\n");
   g_string_append_len (string, s5->str, s5->len);
   g_string_append (string, "\n");
+  g_string_append_len (string, s6->str, s6->len);
+  g_string_append (string, "\n");
 
   g_string_free (s1, TRUE);
   g_string_free (s2, TRUE);
   g_string_free (s3, TRUE);
   g_string_free (s4, TRUE);
   g_string_free (s5, TRUE);
+  g_string_free (s6, TRUE);
 
   g_object_unref (layout);
   g_free (attrs);
@@ -350,40 +380,54 @@ main (int argc, char *argv[])
   GError *error = NULL;
   const gchar *name;
   gchar *path;
+  gboolean opt_legend = 0;
+  GOptionContext *option_context;
+  GOptionEntry entries[] = {
+    { "hex-chars", 0, 0, G_OPTION_ARG_NONE, &opt_hex_chars, "Print all chars in hex", NULL },
+    { "legend", 0, 0, G_OPTION_ARG_NONE, &opt_legend, "Explain the output", NULL },
+    { NULL, 0 },
+  };
+
+  option_context = g_option_context_new ("");
+  g_option_context_add_main_entries (option_context, entries, NULL);
+  g_option_context_set_ignore_unknown_options (option_context, TRUE);
+  if (!g_option_context_parse (option_context, &argc, &argv, &error))
+    {
+      g_error ("failed to parse options: %s", error->message);
+      return 1;
+    }
+  g_option_context_free (option_context);
 
   setlocale (LC_ALL, "");
 
   context = pango_font_map_create_context (pango_cairo_font_map_get_default ());
 
-  /* allow to easily generate expected output for new test cases */
-  if (argc > 1)
+  if (opt_legend)
     {
-      if (strcmp (argv[1], "--legend") == 0)
-        {
-          g_print ("test-break uses the following symbols for log attrs\n\n");
-          g_print ("Breaks:                 Words:                  Graphemes:\n"
-                   " L - mandatory break     b - word boundary       b - grapheme boundary\n"
-                   " l - line break          s - word start\n"
-                   " c - char break          e - word end\n"
-                   "\n"
-                   "Whitespace:             Sentences:\n"
-                   " x - expandable space    b - sentence boundary\n"
-                   " w - whitespace          s - sentence start\n"
-                   "                         e - sentence end\n");
-          return 0;
-        }
-      else if (argv[1][0] != '-')
-        {
-          GString *string;
+      g_print ("test-break uses the following symbols for log attrs\n\n");
+      g_print ("Breaks:                 Words:                  Graphemes:\n"
+               " L - mandatory break     b - word boundary       b - grapheme boundary\n"
+               " l - line break          s - word start\n"
+               " c - char break          e - word end\n"
+               "\n"
+               "Whitespace:             Sentences:              Hyphens:\n"
+               " x - expandable space    b - sentence boundary   i - insert hyphen\n"
+               " w - whitespace          s - sentence start      r - remove preceding\n"
+               "                         e - sentence end\n");
+      return 0;
+    }
 
-          string = g_string_sized_new (0);
-          test_file (argv[1], string);
-          g_print ("%s", string->str);
+  if (argc > 1 && argv[1][0] != '-')
+    {
+      GString *string;
 
-          g_string_free (string, TRUE);
+      string = g_string_sized_new (0);
+      test_file (argv[1], string);
+      g_print ("%s", string->str);
 
-          return 0;
-        }
+      g_string_free (string, TRUE);
+
+      return 0;
     }
 
   g_test_init (&argc, &argv, NULL);
